@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 import os
-from functools import lru_cache
+from functools import cached_property, lru_cache
 from pathlib import Path
 from threading import Lock
 from typing import TYPE_CHECKING, Any, Dict, NamedTuple, Optional, Tuple, Union
@@ -13,15 +13,18 @@ import numpy as np
 import xarray as xr
 from fsspec.implementations.local import LocalFileSystem
 from ome_types import OME
+from resource_backed_dask_array import (
+    ResourceBackedDaskArray,
+    resource_backed_dask_array,
+)
 
 from .. import constants, dimensions, exceptions
 from ..metadata import utils as metadata_utils
 from ..utils import io_utils
-from ..utils.cached_property import cached_property
-from ..utils.dask_proxy import DaskArrayProxy
 from .reader import Reader
 
 if TYPE_CHECKING:
+    from bioformats_jar import _loci
     from fsspec.spec import AbstractFileSystem
 
     from .. import types
@@ -30,21 +33,27 @@ if TYPE_CHECKING:
 try:
     import jpype
     from bioformats_jar import get_loci
-except ImportError:
+except ImportError as e:
     raise ImportError(
         "bioformats_jar is required for this reader. "
-        "Install with `pip install bioformats_jar`"
-    )
+        "Install with `pip install bioformats_jar` or `conda install bioformats_jar`"
+    ) from e
+try:
+    from jgo.jgo import ExecutableNotFound
+except ImportError:
+
+    class ExecutableNotFound(Exception):  # type: ignore
+        ...
 
 
 class BioformatsReader(Reader):
     """Read files using bioformats.
 
     This reader requires `bioformats_jar` to be installed in the environment, and
-    requires the java executable to be available on the path, or via the JAVA_HOME
-    environment variable.
+    requires the java executable to be available on the path (or via the JAVA_HOME
+    environment variable), along with the `mvn` executable.
 
-    To install java with conda, run `conda install -c conda-forge openjdk`.
+    To install java and maven with conda, run `conda install -c conda-forge scyjava`.
     You may need to deactivate/reactivate your environment after installing.  If you
     are *still* getting a `JVMNotFoundException`, try setting JAVA_HOME as follows:
 
@@ -82,6 +91,10 @@ class BioformatsReader(Reader):
     tile_size: Optional[Tuple[int, int]]
         Tuple that sets the tile size of y and x axis, respectively
         By default, it will use optimal values computed by bioformats itself
+    fs_kwargs: Dict[str, Any]
+        Any specific keyword arguments to pass down to the fsspec created filesystem.
+        Default: {}
+
     Raises
     ------
     exceptions.UnsupportedFileFormatError
@@ -109,8 +122,13 @@ class BioformatsReader(Reader):
         options: Dict[str, bool] = {},
         dask_tiles: bool = False,
         tile_size: Optional[Tuple[int, int]] = None,
+        fs_kwargs: Dict[str, Any] = {},
     ):
-        self._fs, self._path = io_utils.pathlike_to_fs(image, enforce_exists=True)
+        self._fs, self._path = io_utils.pathlike_to_fs(
+            image,
+            enforce_exists=True,
+            fs_kwargs=fs_kwargs,
+        )
         # Catch non-local file system
         if not isinstance(self._fs, LocalFileSystem):
             raise ValueError(
@@ -131,12 +149,12 @@ class BioformatsReader(Reader):
                 self._scenes: Tuple[str, ...] = tuple(
                     str(md.getImageName(i)) for i in range(md.getImageCount())
                 )
-        except jpype.JVMNotFoundException:
+        except RuntimeError:
             raise
-        except Exception:
+        except Exception as e:
             raise exceptions.UnsupportedFileFormatError(
                 self.__class__.__name__, self._path
-            )
+            ) from e
 
     @property
     def scenes(self) -> Tuple[str, ...]:
@@ -174,7 +192,11 @@ class BioformatsReader(Reader):
         )
 
     def _to_xarray(self, delayed: bool = True) -> xr.DataArray:
-        with BioFile(self._path, **self._bf_kwargs) as rdr:  # type: ignore
+        with BioFile(
+            self._path,
+            series=self.current_scene_index,
+            **self._bf_kwargs,  # type: ignore
+        ) as rdr:
             image_data = rdr.to_dask() if delayed else rdr.to_numpy()
             _, coords = metadata_utils.get_dims_and_coords_from_ome(
                 ome=rdr.ome_metadata,
@@ -186,7 +208,7 @@ class BioformatsReader(Reader):
             dims=dimensions.DEFAULT_DIMENSION_ORDER_LIST_WITH_SAMPLES
             if rdr.core_meta.is_rgb
             else dimensions.DEFAULT_DIMENSION_ORDER_LIST,
-            coords=coords,  # type: ignore
+            coords=coords,
             attrs={
                 constants.METADATA_UNPROCESSED: rdr.ome_xml,
                 constants.METADATA_PROCESSED: rdr.ome_metadata,
@@ -196,9 +218,7 @@ class BioformatsReader(Reader):
     @staticmethod
     def bioformats_version() -> str:
         """The version of the bioformats_package.jar being used."""
-        from bioformats_jar import get_loci
-
-        return get_loci().__version__
+        return _try_get_loci().__version__
 
 
 class CoreMeta(NamedTuple):
@@ -260,7 +280,7 @@ class BioFile:
     dask_tiles: bool, optional
         Whether to chunk the bioformats dask array by tiles to easily read sub-regions
         with numpy-like array indexing
-        Defaults to false and iamges are read by entire planes
+        Defaults to false and images are read by entire planes
     tile_size: Optional[Tuple[int, int]]
         Tuple that sets the tile size of y and x axis, respectively
         By default, it will use optimal values computed by bioformats itself
@@ -278,20 +298,7 @@ class BioFile:
         dask_tiles: bool = False,
         tile_size: Optional[Tuple[int, int]] = None,
     ):
-        try:
-            loci = get_loci()
-        except jpype.JVMNotFoundException as e:
-            raise type(e)(
-                str(e) + "\n\nBioformatsReader requires a java executable to be "
-                "available in your environment. If you are using conda, you can "
-                "install with `conda install -c conda-forge openjdk`.\n\n"
-                "Note: you may need to reactivate your conda environment after "
-                "installing opendjk. If you still have this error, try:\n\n"
-                "# mac and linux:\n"
-                "export JAVA_HOME=$CONDA_PREFIX\n\n"
-                "# windows:\n"
-                "set JAVA_HOME=%CONDA_PREFIX%\\Library"
-            )
+        loci = _try_get_loci()  # may raise RuntimeError
 
         self._path = str(path)
         self._r = loci.formats.ImageReader()
@@ -314,6 +321,7 @@ class BioFile:
                 mo.set(name, str(value))
             self._r.setMetadataOptions(mo)
 
+        self._current_scene_index = series
         self.open()
         self._lock = Lock()
         self.set_series(series)
@@ -346,6 +354,7 @@ class BioFile:
             self._r.getDimensionOrder(),
             self._r.getResolutionCount(),
         )
+        self._current_scene_index = series
 
     @property
     def core_meta(self) -> CoreMeta:
@@ -354,6 +363,7 @@ class BioFile:
     def open(self) -> None:
         """Open file."""
         self._r.setId(self._path)
+        self._r.setSeries(self._current_scene_index)
 
     def close(self) -> None:
         """Close file."""
@@ -376,21 +386,21 @@ class BioFile:
         """
         return np.asarray(self.to_dask(series))
 
-    def to_dask(self, series: Optional[int] = None) -> DaskArrayProxy:
+    def to_dask(self, series: Optional[int] = None) -> ResourceBackedDaskArray:
         """Create dask array for the specified or current series.
 
         Note: the order of the returned array will *always* be `TCZYX[r]`,
         where `[r]` refers to an optional RGB dimension with size 3 or 4.
         If the image is RGB it will have `ndim==6`, otherwise `ndim` will be 5.
 
-        The returned object is a `DaskArrayProxy`, which is a wrapper on a dask array
-        that ensures the file is open when actually reading (computing) a chunk.  It
-        has all the methods and behavior of a dask array.
-        see :class:`aicsimageio.utils.dask_proxy.DaskArrayProxy`.
+        The returned object is a `ResourceBackedDaskArray`, which is a wrapper on
+        a dask array that ensures the file is open when actually reading (computing)
+        a chunk.  It has all the methods and behavior of a dask array.
+        See: https://github.com/tlambert03/resource-backed-dask-array
 
         Returns
         -------
-        DaskArrayProxy
+        ResourceBackedDaskArray
         """
         if series is not None:
             self._r.setSeries(series)
@@ -409,7 +419,7 @@ class BioFile:
             chunks=chunks,
             dtype=self.core_meta.dtype,
         )
-        return DaskArrayProxy(arr, self)
+        return resource_backed_dask_array(arr, self)
 
     @property
     def closed(self) -> bool:
@@ -531,9 +541,7 @@ class BioFile:
     @classmethod
     def _create_ome_meta(cls) -> Any:
         """create an OMEXMLMetadata object to populate"""
-        from bioformats_jar import get_loci
-
-        loci = get_loci()
+        loci = _try_get_loci()
         if not cls._service:
             factory = loci.common.services.ServiceFactory()
             cls._service = factory.getInstance(loci.formats.services.OMEXMLService)
@@ -542,9 +550,7 @@ class BioFile:
 
 def _pixtype2dtype(pixeltype: int, little_endian: bool) -> np.dtype:
     """Convert a loci.formats PixelType integer into a numpy dtype."""
-    from bioformats_jar import get_loci
-
-    FT = get_loci().formats.FormatTools
+    FT = _try_get_loci().formats.FormatTools
     fmt2type: Dict[int, str] = {
         FT.INT8: "i1",
         FT.UINT8: "u1",
@@ -615,3 +621,36 @@ def _hide_memoization_warning() -> None:
 
     System = jpype.JPackage("java").lang.System
     System.err.close()
+
+
+MAVEN_ERROR_MSG = """
+BioformatsReader requires the maven ('mvn') executable to be
+available in your environment. If you are using conda, you can 
+install with `conda install -c conda-forge scyjava`.
+
+Alternatively, install from https://maven.apache.org/download.cgi
+"""
+
+JAVA_ERROR_MSG = """
+BioformatsReader requires a java executable to be available
+in your environment. If you are using conda, you can install
+with `conda install -c conda-forge scyjava`.
+
+Note: you may need to reactivate your conda environment after 
+installing opendjk. If you still have this error, try:
+
+# mac and linux:
+export JAVA_HOME=$CONDA_PREFIX
+
+# windows:
+set JAVA_HOME=%CONDA_PREFIX%\\Library
+"""
+
+
+def _try_get_loci() -> _loci.__module_protocol__:
+    try:
+        return get_loci()
+    except ExecutableNotFound as e:
+        raise RuntimeError(MAVEN_ERROR_MSG) from e
+    except jpype.JVMNotFoundException as e:
+        raise RuntimeError(JAVA_ERROR_MSG) from e
