@@ -47,6 +47,9 @@ class OmeTiffReader(TiffReader):
         Should the OME XML metadata found in the file be cleaned for known
         AICSImageIO 3.x and earlier created errors.
         Default: True (Clean the metadata for known errors)
+    fs_kwargs: Dict[str, Any]
+        Any specific keyword arguments to pass down to the fsspec created filesystem.
+        Default: {}
 
     Notes
     -----
@@ -92,17 +95,17 @@ class OmeTiffReader(TiffReader):
 
         # xml parse errors
         except ET.ParseError as e:
-            log.error(f"Failed to parse XML for the provided file. Error: {e}")
+            log.debug(f"Failed to parse XML for the provided file. Error: {e}")
             return False
 
         # invalid OME XMl
         except XMLSchemaValidationError as e:
-            log.error(f"OME XML validation failed. Error: {e}")
+            log.debug(f"OME XML validation failed. Error: {e}")
             return False
 
         # cant connect to external schema resource (no internet conection)
         except URLError as e:
-            log.error(
+            log.debug(
                 f"Could not validate OME XML against referenced schema "
                 f"(no internet connection). "
                 f"Error: {e}"
@@ -114,10 +117,15 @@ class OmeTiffReader(TiffReader):
         image: types.PathLike,
         chunk_dims: Union[str, List[str]] = DEFAULT_CHUNK_DIMS,
         clean_metadata: bool = True,
+        fs_kwargs: Dict[str, Any] = {},
         **kwargs: Any,
     ):
         # Expand details of provided image
-        self._fs, self._path = io_utils.pathlike_to_fs(image, enforce_exists=True)
+        self._fs, self._path = io_utils.pathlike_to_fs(
+            image,
+            enforce_exists=True,
+            fs_kwargs=fs_kwargs,
+        )
 
         # Store params
         if isinstance(chunk_dims, str):
@@ -235,7 +243,7 @@ class OmeTiffReader(TiffReader):
         return xr.DataArray(
             image_data,
             dims=dims,
-            coords=coords,  # type: ignore
+            coords=coords,
             attrs={
                 constants.METADATA_UNPROCESSED: tiff_tags,
                 constants.METADATA_PROCESSED: self._ome,
