@@ -31,7 +31,6 @@ TIFF_IMAGE_DESCRIPTION_TAG_INDEX = 270
 
 
 class TiffGlobReader(Reader):
-
     r"""
     Wraps the tifffile imread API to provide the same aicsimageio Reader API but for
     multifile tiff datasets (and other tifffile supported) images.
@@ -73,6 +72,9 @@ class TiffGlobReader(Reader):
     single_file_dims : Optional[Tuple]
         Dimensions that correspond to the data dimensions of a single file in the glob.
         Default : ('Y', 'X')
+    fs_kwargs: Dict[str, Any]
+        Any specific keyword arguments to pass down to the fsspec created filesystem.
+        Default: {}
 
     Examples
     --------
@@ -134,6 +136,7 @@ class TiffGlobReader(Reader):
             DimensionNames.SpatialY,
             DimensionNames.SpatialX,
         ),
+        fs_kwargs: Dict[str, Any] = {},
         **kwargs: Any,
     ):
 
@@ -188,7 +191,10 @@ class TiffGlobReader(Reader):
         self._all_files = self._all_files.sort_values(sort_order).reset_index(drop=True)
 
         # run tests on a single file (?)
-        self._fs, self._path = io_utils.pathlike_to_fs(self._all_files.iloc[0].filename)
+        self._fs, self._path = io_utils.pathlike_to_fs(
+            self._all_files.iloc[0].filename,
+            fs_kwargs=fs_kwargs,
+        )
 
         # Store params
         if isinstance(chunk_dims, str):
@@ -243,12 +249,7 @@ class TiffGlobReader(Reader):
         if single_file_shape is None:
             with self._fs.open(self._path) as open_resource:
                 with TiffFile(open_resource) as tiff:
-                    if tiff.is_shaped:
-                        self._single_file_shape = tuple(
-                            tiff.shaped_metadata[0]["shape"]
-                        )
-                    elif len(tiff.series) == 1:
-                        self._single_file_shape = tiff.series[0].shape
+                    self._single_file_shape = tiff.series[0].shape
 
         else:
             self._single_file_shape = single_file_shape
